@@ -126,59 +126,62 @@ static const filter_map_t filterRangeMap =
 {
     { "Anthony Lees",                        1.3 },
     { "Antony Crowther (Ratt)",              1.1 },
-    { "Barry Leitch (The Jackal)",           0.05 },
+    { "Barry Leitch (The Jackal)",           0.3 },
     { "Ben Daglish",                         0.6 },
+    { "Carsten Berggreen (Scarzix)",         0.7 },
     { "Charles Deenen",                      0.2 },
-    { "Chris H\xFClsbeck",                   0.6 },
-    { "David Dunn",                          0.15 },
-    { "David Dunn & Aidan Bell",             0.15 },
+    { "Chris H\xFClsbeck",                   0.9 },
+    { "David Dunn",                          0.1 },
+    { "David Dunn & Aidan Bell",             0.1 },
     { "David Whittaker",                     0.15 },
-    { "Thomas Mogensen (DRAX)",              0.3 },
     { "Edwin van Santen",                    0.5 },
     { "Edwin van Santen & Falco Paul",       0.4 }, // 20th Century Composers
     { "Edwin van Santen & Venom",            0.4 }, // 20th Century Composers
     { "Falco Paul",                          0.15 },
     { "Falco Paul & Edwin van Santen",       0.4 }, // 20th Century Composers
     { "Figge Wasberger (Fegolhuzz)",         0.25 },
-    { "Fred Gray",                           0.18 },
+    { "Fred Gray",                           0.4 },
     { "Geir Tjelta",                         0.5 },
     { "Geoff Follin",                        0.85 },
     { "Georg Feil",                          0.2 },
-    { "Glenn Rune Gallefoss",                0.2 },
-    { "Graham Jarvis & Rob Hartshorne",      0.25 },
+    { "Glenn Rune Gallefoss",                1.3 },
+    { "Graham Jarvis & Rob Hartshorne",      0.25 }, // Clever Music
     { "Jason Page",                          0.35 },
     { "Jeroen Tel",                          0.35 },
     { "Johannes Bjerregaard",                0.35 },
     { "Jonathan Dunn",                       0.25 },
     { "Jouni Ikonen (Mixer)",                0.25 },
     { "Jori Olkkonen",                       0.15 },
-    { "Jori Olkkonen (Yip)",                 0.15 },
+    { "Jori Olkkonen (Yip)",                 0.35 },
     { "Kim Christensen (Future Freak)",      0.35 },
     { "Linus \xC5kesson (lft)",              0.3 },
-    { "Mark Cooksey",                        0.25 },
-    { "Markus M\xFCller (Superbrain)",       0.3 },
-    { "Martin Galway",                       1.0 },
+    { "Mark Cooksey",                        0.4 },
+    { "Mark Wilson",                         0.2 },
+    { "Markus M\xFCller (Superbrain)",       0.5 },
+    { "Martin Galway",                       0.65 },
     { "Martin Walker",                       0.15 },
     { "Matt Gray",                           0.3 },
-    { "Michael Hendriks",                    0.25 },
-    { "Mitch & Dane",                        0.75 },
-    { "M. Nilsson-Vonderburgh (Mic)",        0.25 },
-    { "M. Nilsson-Vonderburgh (Mitch)",      0.25 },
-    { "M. Nilsson-Vonderburgh (Yankee)",     0.25 },
+    { "Michael Hendriks",                    0.35 },
+    { "Mitch & Dane",                        0.85 },
+    { "M. Nilsson-Vonderburgh (Mic)",        0.3 },
+    { "M. Nilsson-Vonderburgh (Mitch)",      0.3 },
+    { "M. Nilsson-Vonderburgh (Yankee)",     0.3 },
+    { "NM156",                               0.7 },
     { "Neil Brennan",                        0.25 },
     { "Peter Clarke",                        0.2 },
     { "Pex Tufvesson (Mahoney)",             0.35 },
     { "Pex Tufvesson (Zax)",                 0.35 },
     { "Renato Brosowski (Zoci-Joe)",         0.3 },
-    { "Reyn Ouwehand",                       0.25 },
+    { "Reyn Ouwehand",                       0.8 },
     { "Richard Joseph",                      0.3 },
     { "Rob Hubbard",                         0.35 },
     { "Russell Lieblich",                    0.25 },
-    { "Stellan Andersson (Dane)",            0.75 },
+    { "Stellan Andersson (Dane)",            0.85 },
     { "Steve Turner",                        0.6 },
     { "Tim Follin",                          0.5 },
     { "Thomas E. Petersen (Laxity)",         0.3 },
     { "Thomas E. Petersen (TSS)",            0.3 },
+    { "Thomas Mogensen (DRAX)",              0.3 },
 };
 #else
 static const filter_map_t filterCurveMap =
@@ -328,7 +331,7 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
     m_filename(""),
     m_fcurve(-1.0),
     m_quietLevel(0),
-    songlengthDB(SLDB_NONE),
+    songlengthDB(sldb_t::NONE),
     m_cpudebug(false),
     m_autofilter(false)
 {
@@ -399,14 +402,14 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
             else if (emulation.engine.compare(TEXT("HARDSID")) == 0)
             {
                 m_driver.sid    = EMU_HARDSID;
-                m_driver.output = OUT_NULL;
+                m_driver.output = output_t::NONE;
             }
 #endif
 #ifdef HAVE_SIDPLAYFP_BUILDERS_EXSID_H
             else if (emulation.engine.compare(TEXT("EXSID")) == 0)
             {
                 m_driver.sid    = EMU_EXSID;
-                m_driver.output = OUT_NULL;
+                m_driver.output = output_t::NONE;
             }
 #endif
             else if (emulation.engine.compare(TEXT("NONE")) == 0)
@@ -418,7 +421,7 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
 
     m_verboseLevel = (m_iniCfg.sidplay2()).verboseLevel;
 
-    createOutput (OUT_NULL, nullptr);
+    createOutput (output_t::NONE, nullptr);
     createSidEmu (EMU_NONE, nullptr);
 
     uint8_t *kernalRom = loadRom((m_iniCfg.sidplay2()).kernalRom, 8192, TEXT("kernal"));
@@ -462,7 +465,7 @@ std::string ConsolePlayer::getFileName(const SidTuneInfo *tuneInfo, const char*
 }
 
 // Create the output object to process sound buffer
-bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
+bool ConsolePlayer::createOutput (output_t driver, const SidTuneInfo *tuneInfo)
 {
     // Remove old audio driver
     m_driver.null.close ();
@@ -477,11 +480,11 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
     // Create audio driver
     switch (driver)
     {
-    case OUT_NULL:
+    case output_t::NONE:
         m_driver.device = &m_driver.null;
     break;
 
-    case OUT_SOUNDCARD:
+    case output_t::SOUNDCARD:
         try
         {
             m_driver.device = new audioDrv();
@@ -492,7 +495,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
         }
     break;
 
-    case OUT_WAV:
+    case output_t::WAV:
         try
         {
             std::string title = getFileName(tuneInfo, WavFile::extension());
@@ -507,7 +510,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
         }
     break;
 
-    case OUT_AU:
+    case output_t::AU:
         try
         {
             std::string title = getFileName(tuneInfo, auFile::extension());
@@ -527,7 +530,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
     if (!m_driver.device)
     {
         m_driver.device = &m_driver.null;
-        displayError (ERR_NOT_ENOUGH_MEMORY);
+        displayError (errnum_t::NOT_ENOUGH_MEMORY);
         return false;
     }
 
@@ -545,7 +548,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
             err = true;
 
         // Can't open the same driver twice
-        if (driver != OUT_NULL)
+        if (driver != output_t::NONE)
         {
             if (!m_driver.null.open(m_driver.cfg))
                 err = true;
@@ -740,7 +743,7 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
     {
         if (emu > EMU_DEFAULT)
         {   // No sid emulation?
-            displayError (ERR_NOT_ENOUGH_MEMORY);
+            displayError (errnum_t::NOT_ENOUGH_MEMORY);
             return false;
         }
     }
@@ -795,7 +798,16 @@ bool ConsolePlayer::open (void)
         return false;
     }
 #ifdef FEAT_REGS_DUMP_SID
-    m_freqTable = (tuneInfo->clockSpeed() == SidTuneInfo::CLOCK_NTSC) ? freqTableNtsc : freqTablePal;
+    if (
+            (
+                (m_engCfg.defaultC64Model == SidConfig::NTSC) &&
+                (m_engCfg.forceC64Model || (tuneInfo->clockSpeed() != SidTuneInfo::CLOCK_PAL))
+            ) ||
+            (tuneInfo->clockSpeed() == SidTuneInfo::CLOCK_NTSC)
+    )
+        m_freqTable = freqTableNtsc;
+    else
+        m_freqTable = freqTablePal;
 #endif
     // Start the player.  Do this by fast
     // forwarding to the start position
@@ -818,7 +830,7 @@ bool ConsolePlayer::open (void)
     if (!m_timer.valid)
     {
 #ifdef FEAT_NEW_SONLEGTH_DB
-        const int_least32_t length = songlengthDB == SLDB_MD5 ? m_database.lengthMs(m_tune) : (m_database.length(m_tune) * 1000);
+        const int_least32_t length = songlengthDB == sldb_t::MD5 ? m_database.lengthMs(m_tune) : (m_database.length(m_tune) * 1000);
 #else
         const int_least32_t length = m_database.length(m_tune) * 1000;
 #endif
@@ -866,7 +878,7 @@ void ConsolePlayer::close ()
         m_driver.selected->reset ();
 
     // Shutdown drivers, etc
-    createOutput    (OUT_NULL, nullptr);
+    createOutput    (output_t::NONE, nullptr);
     createSidEmu    (EMU_NONE, nullptr);
     m_engine.load   (nullptr);
     m_engine.config (m_engCfg);
@@ -874,8 +886,10 @@ void ConsolePlayer::close ()
     if (m_quietLevel < 2)
     {   // Correctly leave ansi mode and get prompt to
         // end up in a suitable location
-        if ((m_iniCfg.console ()).ansi)
+        if ((m_iniCfg.console ()).ansi) {
+            cerr << '\x1b' << "[?25h";
             cerr << '\x1b' << "[0m";
+        }
 #ifndef _WIN32
         cerr << endl;
 #endif
@@ -995,7 +1009,11 @@ uint_least32_t ConsolePlayer::getBufSize()
     else if ((m_timer.stop != 0) && (m_timer.current >= m_timer.stop))
     {
         m_state = playerExit;
-        for (;;)
+        if (m_track.loop)
+        {
+            m_state = playerRestart;
+        }
+        else
         {
             if (m_track.single)
                 return 0;
@@ -1006,10 +1024,7 @@ uint_least32_t ConsolePlayer::getBufSize()
             if (m_track.selected == m_track.first)
                 return 0;
             m_state = playerRestart;
-            break;
         }
-        if (m_track.loop)
-            m_state = playerRestart;
     }
     else
     {
