@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2023 Leandro Nini
+ * Copyright 2011-2024 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -50,14 +50,35 @@
 #  endif
 #endif
 
-typedef enum { black, red, green, yellow, blue, magenta, cyan, white }
-    player_colour_t;
-typedef enum { tableStart, tableMiddle, tableSeparator, tableEnd }
-    player_table_t;
+enum class color_t
+{
+    black,
+    red,
+    green,
+    yellow,
+    blue,
+    magenta,
+    cyan,
+    white
+};
+
+enum class table_t
+{
+    start,
+    middle,
+    separator,
+    end
+};
+
 typedef enum
 {
-    playerError = 0, playerRunning, playerPaused, playerStopped,
-    playerRestart, playerExit, playerFast = 128,
+    playerError = 0,
+    playerRunning,
+    playerPaused,
+    playerStopped,
+    playerRestart,
+    playerExit,
+    playerFast = 128,
     playerFastRestart = playerRestart | playerFast,
     playerFastExit = playerExit | playerFast
 } player_state_t;
@@ -68,31 +89,46 @@ typedef enum
     Still allows wav generation */
     EMU_NONE = 0,
     /* The following require a soundcard */
-    EMU_DEFAULT, EMU_RESIDFP, EMU_RESID,
+    EMU_DEFAULT,
+    EMU_RESIDFP,
+    EMU_RESID,
     /* The following should disable the soundcard */
-    EMU_HARDSID, EMU_EXSID, EMU_SIDSTATION, EMU_COMMODORE,
-    EMU_SIDSYN, EMU_END} SIDEMUS;
+    EMU_HARDSID,
+    EMU_EXSID,
+    EMU_SIDSTATION,
+    EMU_COMMODORE,
+    EMU_SIDSYN,
+    EMU_END
+} SIDEMUS;
 
-typedef enum
+enum class output_t
 {
     /* Define possible output sources */
-    OUT_NULL = 0,
+    NONE,
     /* Hardware */
-    OUT_SOUNDCARD,
+    SOUNDCARD,
     /* File creation support */
-    OUT_WAV, OUT_AU, OUT_END
-} OUTPUTS;
-
-// Error and status message numbers.
-enum
-{
-    ERR_SYNTAX = 0,
-    ERR_NOT_ENOUGH_MEMORY,
-    ERR_SIGHANDLER,
-    ERR_FILE_OPEN
+    WAV,
+    AU,
+    END
 };
 
-void displayError (const char *arg0, unsigned int num);
+// Error and status message numbers.
+enum class errnum_t
+{
+    NOT_ENOUGH_MEMORY,
+    SIGHANDLER
+};
+
+// Songlength DB.
+enum class sldb_t
+{
+    NONE,
+    TXT,
+    MD5
+};
+
+void displayError (const char *arg0, errnum_t num);
 
 
 // Grouped global variables
@@ -139,9 +175,9 @@ private:
     uint_least8_t      m_quietLevel;
     uint_least8_t      m_verboseLevel;
 
-    bool               m_cpudebug;
+    sldb_t             songlengthDB;
 
-    bool               newSonglengthDB;
+    bool               m_cpudebug;
 
     bool               m_autofilter;
 
@@ -166,7 +202,7 @@ private:
 
     struct m_driver_t
     {
-        OUTPUTS        output;   // Selected output type
+        output_t       output;   // Selected output type
         SIDEMUS        sid;      // Sid emulation
         bool           file;     // File based driver
         bool           info;     // File metadata
@@ -203,17 +239,17 @@ private:
 
 private:
     // Console
-    void consoleColour  (player_colour_t colour, bool bold);
-    void consoleTable   (player_table_t table);
+    void consoleColour  (color_t colour, bool bold);
+    void consoleTable   (table_t table);
     void consoleRestore (void);
 
     // Command line args
-    void displayArgs    (const char *arg = NULL);
+    void displayArgs    (const char *arg = nullptr);
 
-    bool createOutput   (OUTPUTS driver, const SidTuneInfo *tuneInfo);
+    bool createOutput   (output_t driver, const SidTuneInfo *tuneInfo);
     bool createSidEmu   (SIDEMUS emu, const SidTuneInfo *tuneInfo);
     void displayError   (const char *error);
-    void displayError   (unsigned int num) { ::displayError (m_name, num); }
+    void displayError   (errnum_t num) { ::displayError (m_name, num); }
     void decodeKeys     (void);
     void updateDisplay();
     void emuflush       (void);
@@ -231,7 +267,7 @@ private:
 
 public:
     ConsolePlayer (const char * const name);
-    virtual ~ConsolePlayer() {}
+    virtual ~ConsolePlayer() = default;
 
     int  args  (int argc, const char *argv[]);
     bool open  (void);
